@@ -51,7 +51,6 @@ CREATE TABLE rosterusers (
 ) ENGINE=InnoDB CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;
 
 CREATE UNIQUE INDEX i_rosteru_user_jid ON rosterusers(username(75), jid(75));
-CREATE INDEX i_rosteru_username ON rosterusers(username);
 CREATE INDEX i_rosteru_jid ON rosterusers(jid);
 
 CREATE TABLE rostergroups (
@@ -77,7 +76,6 @@ CREATE TABLE sr_user (
 ) ENGINE=InnoDB CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;
 
 CREATE UNIQUE INDEX i_sr_user_jid_group ON sr_user(jid(75), grp(75));
-CREATE INDEX i_sr_user_jid ON sr_user(jid);
 CREATE INDEX i_sr_user_grp ON sr_user(grp);
 
 CREATE TABLE spool (
@@ -174,7 +172,6 @@ CREATE TABLE privacy_list (
     created_at timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP
 ) ENGINE=InnoDB CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;
 
-CREATE INDEX i_privacy_list_username  USING BTREE ON privacy_list(username);
 CREATE UNIQUE INDEX i_privacy_list_username_name USING BTREE ON privacy_list (username(75), name(75));
 
 CREATE TABLE privacy_list_data (
@@ -199,7 +196,6 @@ CREATE TABLE private_storage (
     created_at timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP
 ) ENGINE=InnoDB CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;
 
-CREATE INDEX i_private_storage_username USING BTREE ON private_storage(username);
 CREATE UNIQUE INDEX i_private_storage_username_namespace USING BTREE ON private_storage(username(75), namespace(75));
 
 -- Not tested in mysql
@@ -307,7 +303,6 @@ CREATE TABLE muc_online_users (
 ) ENGINE=InnoDB CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;
 
 CREATE UNIQUE INDEX i_muc_online_users USING BTREE ON muc_online_users(username(75), server(75), resource(75), name(75), host(75));
-CREATE INDEX i_muc_online_users_us USING BTREE ON muc_online_users(username(75), server(75));
 
 CREATE TABLE muc_room_subscribers (
    room varchar(191) NOT NULL,
@@ -374,7 +369,6 @@ CREATE TABLE route (
 ) ENGINE=InnoDB CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;
 
 CREATE UNIQUE INDEX i_route ON route(domain(75), server_host(75), node(75), pid(75));
-CREATE INDEX i_route_domain ON route(domain(75));
 
 CREATE TABLE bosh (
     sid text NOT NULL,
@@ -433,7 +427,6 @@ CREATE TABLE mix_participant (
 ) ENGINE=InnoDB CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;
 
 CREATE UNIQUE INDEX i_mix_participant ON mix_participant (channel(191), service(191), username(191), domain(191));
-CREATE INDEX i_mix_participant_chan_serv ON mix_participant (channel(191), service(191));
 
 CREATE TABLE mix_subscription (
     channel text NOT NULL,
@@ -445,9 +438,7 @@ CREATE TABLE mix_subscription (
 ) ENGINE=InnoDB CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;
 
 CREATE UNIQUE INDEX i_mix_subscription ON mix_subscription (channel(153), service(153), username(153), domain(153), node(153));
-CREATE INDEX i_mix_subscription_chan_serv_ud ON mix_subscription (channel(191), service(191), username(191), domain(191));
 CREATE INDEX i_mix_subscription_chan_serv_node ON mix_subscription (channel(191), service(191), node(191));
-CREATE INDEX i_mix_subscription_chan_serv ON mix_subscription (channel(191), service(191));
 
 CREATE TABLE mix_pam (
     username text NOT NULL,
@@ -458,7 +449,6 @@ CREATE TABLE mix_pam (
 ) ENGINE=InnoDB CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;
 
 CREATE UNIQUE INDEX i_mix_pam ON mix_pam (username(191), channel(191), service(191));
-CREATE INDEX i_mix_pam_u ON mix_pam (username(191));
 
 CREATE TABLE mqtt_pub (
     username varchar(191) NOT NULL,
