@@ -398,15 +398,29 @@ user_exists(_User, <<"">>) ->
 user_exists(User, Server) ->
     case validate_credentials(User, Server) of
 	{ok, LUser, LServer} ->
-	    lists:any(
-	      fun(M) ->
-		      case db_user_exists(LUser, LServer, M) of
-			  {error, _} ->
-			      false;
-			  Else ->
-			      Else
-		      end
-	      end, auth_modules(LServer));
+	    {Exists, PerformExternalUserCheck} =
+	    lists:foldl(
+		fun(M, {Exists0, PerformExternalUserCheck0}) ->
+		    case db_user_exists(LUser, LServer, M) of
+			{{error, _}, Check} ->
+			    {Exists0, PerformExternalUserCheck0 orelse Check};
+			{Else, Check2} ->
+			    {Exists0 orelse Else, PerformExternalUserCheck0 orelse Check2}
+		    end
+		end, {false, false}, auth_modules(LServer)),
+	    case (not Exists) andalso PerformExternalUserCheck andalso
+		 ejabberd_option:auth_external_user_exists_check(Server) andalso
+		 gen_mod:is_loaded(Server, mod_last) of
+		true ->
+		    case mod_last:get_last_info(User, Server) of
+			not_found ->
+			    false;
+			_ ->
+			    true
+		    end;
+		_ ->
+		    Exists
+	    end;
 	_ ->
 	    false
     end.
@@ -420,11 +434,11 @@ user_exists_in_other_modules_loop([], _User, _Server) ->
     false;
 user_exists_in_other_modules_loop([AuthModule | AuthModules], User, Server) ->
     case db_user_exists(User, Server, AuthModule) of
-	true ->
+	{true, _} ->
 	    true;
-	false ->
+	{false, _} ->
 	    user_exists_in_other_modules_loop(AuthModules, User, Server);
-	{error, _} ->
+	{{error, _}, _} ->
 	    maybe
     end.
 
@@ -628,9 +642,9 @@ db_get_password(User, Server, Mod) ->
 db_user_exists(User, Server, Mod) ->
     case db_get_password(User, Server, Mod) of
 	{ok, _} ->
-	    true;
+	    {true, false};
 	not_found ->
-	    false;
+	    {false, false};
 	error ->
 	    case {Mod:store_type(Server), use_cache(Mod, Server)} of
 		{external, true} ->
@@ -649,18 +663,18 @@ db_user_exists(User, Server, Mod) ->
 			  end,
 		    case Val of
 			{ok, _} ->
-			    true;
+			    {true, Mod /= ejabberd_auth_anonymous} ;
 			not_found ->
-			    false;
+			    {false, Mod /= ejabberd_auth_anonymous};
 			error ->
-			    false;
+			    {false, Mod /= ejabberd_auth_anonymous};
 			{error, _} = Err ->
-			    Err
+			    {Err, Mod /= ejabberd_auth_anonymous}
 		    end;
 		{external, false} ->
-		    ets_cache:untag(Mod:user_exists(User, Server));
+		    {ets_cache:untag(Mod:user_exists(User, Server)), Mod /= ejabberd_auth_anonymous};
 		_ ->
-		    false
+		    {false, false}
 	    end
     end.
 
