@@ -5,7 +5,7 @@
 %%% Created : 16 Mar 2019 by Mickael Remond <mremond@process-one.net>
 %%%
 %%%
-%%% ejabberd, Copyright (C) 2002-2022   ProcessOne
+%%% ejabberd, Copyright (C) 2002-2023   ProcessOne
 %%%
 %%% This program is free software; you can redistribute it and/or
 %%% modify it under the terms of the GNU General Public License as
@@ -146,6 +146,9 @@ check_jwt_token(User, Server, Token) ->
         {false, _, _} ->
             false
     catch
-        error:{badarg, _} ->
+        A:B ->
+            ?DEBUG("jose_jwt:verify failed ~n for account ~p@~p~n "
+                   " JWK and token: ~p~n with error: ~p",
+                   [User, Server, {JWK, Token}, {A, B}]),
             false
     end.
