@@ -39,6 +39,7 @@
 -include("logger.hrl").
 -include_lib("xmpp/include/xmpp.hrl").
 -include("ejabberd_http.hrl").
+-include("ejabberd_stacktrace.hrl").
 -include_lib("kernel/include/file.hrl").
 
 -record(state, {sockmod,
@@ -370,7 +371,15 @@ process(Handlers, Request) ->
 			HandlerModule:socket_handoff(
 			  LocalPath, Request, HandlerOpts);
 		    false ->
-			HandlerModule:process(LocalPath, Request)
+                        try
+                            HandlerModule:process(LocalPath, Request)
+                        catch
+                            ?EX_RULE(Class, Reason, Stack) ->
+                                ?ERROR_MSG(
+                                   "HTTP handler crashed: ~s",
+                                   [misc:format_exception(2, Class, Reason, ?EX_STACK(Stack))]),
+                                erlang:raise(Class, Reason, ?EX_STACK(Stack))
+                        end
 		end,
             ejabberd_hooks:run(http_request_debug, [{LocalPath, Request}]),
             R;
