@@ -5,7 +5,7 @@
 %%% Created : 17 Nov 2016 by Christophe Romain <christophe.romain@process-one.net>
 %%%
 %%%
-%%% ejabberd, Copyright (C) 2002-2022   ProcessOne
+%%% ejabberd, Copyright (C) 2002-2023   ProcessOne
 %%%
 %%% This program is free software; you can redistribute it and/or
 %%% modify it under the terms of the GNU General Public License as
@@ -172,7 +172,10 @@ change_table_copy_type(Name, TabDef) ->
     if NewType /= CurrType ->
 	    ?INFO_MSG("Changing Mnesia table '~ts' from ~ts to ~ts",
 		      [Name, CurrType, NewType]),
-	    mnesia_op(change_table_copy_type, [Name, node(), NewType]);
+	    if CurrType == unknown -> mnesia_op(add_table_copy, [Name, node(), NewType]);
+		true ->
+		    mnesia_op(change_table_copy_type, [Name, node(), NewType])
+	    end;
        true ->
 	    {atomic, ok}
     end.
