@@ -244,10 +244,9 @@ terminate(_Reason, _State) ->
 
 code_change(_OldVsn, State, _Extra) -> {ok, State}.
 
-
 get_client_identity(<<"">>, Ctx) ->
     {ok, {Ctx, {client, unknown_client}}};
-get_client_identity({client, ClientID}, Ctx) ->
+get_client_identity(ClientID, Ctx) when is_binary(ClientID) ->
     {ok, {Ctx, {client, ClientID}}}.
 
 verify_redirection_uri(_ClientID, RedirectURI, Ctx) ->
@@ -753,6 +752,7 @@ json_error(Code, Error, Reason) ->
     json_response(Code, Body).
 
 json_error_desc(access_denied)          -> <<"Access denied">>;
+json_error_desc(badpass)                -> <<"Bad password">>;
 json_error_desc(unsupported_grant_type) -> <<"Unsupported grant type">>;
 json_error_desc(invalid_scope)          -> <<"Invalid scope">>.
 
