@@ -81,6 +81,8 @@ opt_type(auth_password_format) ->
     econf:enum([plain, scram]);
 opt_type(auth_scram_hash) ->
     econf:enum([sha, sha256, sha512]);
+opt_type(auth_external_user_exists_check) ->
+    econf:bool();
 opt_type(auth_use_cache) ->
     econf:bool();
 opt_type(c2s_cafile) ->
@@ -123,7 +125,9 @@ opt_type(captcha_host) ->
 opt_type(captcha_limit) ->
     econf:pos_int(infinity);
 opt_type(captcha_url) ->
-    econf:url();
+    econf:either(
+      econf:url(),
+      econf:enum([auto, undefined]));
 opt_type(certfiles) ->
     econf:list(econf:binary());
 opt_type(cluster_backend) ->
@@ -181,6 +185,8 @@ opt_type(hosts) ->
     econf:non_empty(econf:list(econf:domain(), [unique]));
 opt_type(include_config_file) ->
     econf:any();
+opt_type(install_contrib_modules) ->
+    econf:list(econf:atom());
 opt_type(language) ->
     econf:lang();
 opt_type(ldap_backups) ->
@@ -254,6 +260,8 @@ opt_type(net_ticktime) ->
     econf:timeout(second);
 opt_type(new_sql_schema) ->
     econf:bool();
+opt_type(update_sql_schema) ->
+    econf:bool();
 opt_type(oauth_access) ->
     econf:acl();
 opt_type(oauth_cache_life_time) ->
@@ -420,6 +428,8 @@ opt_type(sql_username) ->
     econf:binary();
 opt_type(sql_prepared_statements) ->
     econf:bool();
+opt_type(sql_flags) ->
+    econf:list_or_single(econf:enum([mysql_alternative_upsert]), [sorted, unique]);
 opt_type(trusted_proxies) ->
     econf:either(all, econf:list(econf:ip_mask()));
 opt_type(use_cache) ->
@@ -515,6 +525,7 @@ options() ->
      {access_rules, []},
      {acme, #{}},
      {allow_contrib_modules, true},
+     {install_contrib_modules, []},
      {allow_multiple_connections, false},
      {anonymous_protocol, sasl_anon},
      {api_permissions,
@@ -535,6 +546,7 @@ options() ->
      {auth_opts, []},
      {auth_password_format, plain},
      {auth_scram_hash, sha},
+     {auth_external_user_exists_check, true},
      {auth_use_cache,
       fun(Host) -> ejabberd_config:get_option({use_cache, Host}) end},
      {c2s_cafile, undefined},
@@ -546,7 +558,7 @@ options() ->
      {captcha_cmd, undefined},
      {captcha_host, <<"">>},
      {captcha_limit, infinity},
-     {captcha_url, undefined},
+     {captcha_url, auto},
      {certfiles, undefined},
      {cluster_backend, mnesia},
      {cluster_nodes, []},
@@ -597,6 +609,7 @@ options() ->
      {negotiation_timeout, timer:seconds(30)},
      {net_ticktime, timer:seconds(60)},
      {new_sql_schema, ?USE_NEW_SQL_SCHEMA_DEFAULT},
+     {update_sql_schema, false},
      {oauth_access, none},
      {oauth_cache_life_time,
       fun(Host) -> ejabberd_config:get_option({cache_life_time, Host}) end},
@@ -703,6 +716,7 @@ options() ->
      {sql_start_interval, timer:seconds(30)},
      {sql_username, <<"ejabberd">>},
      {sql_prepared_statements, true},
+     {sql_flags, []},
      {trusted_proxies, []},
      {validate_stream, false},
      {websocket_origin, []},
@@ -734,6 +748,7 @@ globals() ->
      fqdn,
      hosts,
      host_config,
+     install_contrib_modules,
      listen,
      loglevel,
      log_rotate_count,
@@ -744,6 +759,7 @@ globals() ->
      negotiation_timeout,
      net_ticktime,
      new_sql_schema,
+     update_sql_schema,
      node_start,
      oauth_cache_life_time,
      oauth_cache_missed,
