@@ -73,7 +73,7 @@
 -record(state,
 	{db_ref               :: undefined | pid(),
 	 db_type = odbc       :: pgsql | mysql | sqlite | odbc | mssql,
-	 db_version           :: undefined | non_neg_integer(),
+	 db_version           :: undefined | non_neg_integer() | {non_neg_integer(), atom(), non_neg_integer()},
 	 reconnect_count = 0  :: non_neg_integer(),
 	 host                 :: binary(),
 	 pending_requests     :: p1_queue:queue(),
@@ -93,15 +93,16 @@
 -endif.
 
 -type state() :: #state{}.
--type sql_query_simple() :: [sql_query() | binary()] | #sql_query{} |
-			    fun(() -> any()) | fun((atom(), _) -> any()).
--type sql_query() :: sql_query_simple() |
-		     [{atom() | {atom(), any()}, sql_query_simple()}].
--type sql_query_result() :: {updated, non_neg_integer()} |
-                            {error, binary() | atom()} |
-                            {selected, [binary()], [[binary()]]} |
-                            {selected, [any()]} |
-			    ok.
+-type sql_query_simple(T) :: [sql_query(T) | binary()] | binary() |
+                             #sql_query{} |
+                             fun(() -> T) | fun((atom(), _) -> T).
+-type sql_query(T) :: sql_query_simple(T) |
+                      [{atom() | {atom(), any()}, sql_query_simple(T)}].
+-type sql_query_result(T) :: {updated, non_neg_integer()} |
+                             {error, binary() | atom()} |
+                             {selected, [binary()], [[binary()]]} |
+                             {selected, [any()]} |
+                             T.
 
 %%%----------------------------------------------------------------------
 %%% API
@@ -112,14 +113,14 @@ start_link(Host, I) ->
     p1_fsm:start_link({local, Proc}, ?MODULE, [Host],
 		      fsm_limit_opts() ++ ?FSMOPTS).
 
--spec sql_query(binary(), sql_query()) -> sql_query_result().
+-spec sql_query(binary(), sql_query(T)) -> sql_query_result(T).
 sql_query(Host, Query) ->
     sql_call(Host, {sql_query, Query}).
 
 %% SQL transaction based on a list of queries
 %% This function automatically
--spec sql_transaction(binary(), [sql_query()] | fun(() -> any())) ->
-                             {atomic, any()} |
+-spec sql_transaction(binary(), [sql_query(T)] | fun(() -> T)) ->
+                             {atomic, T} |
                              {aborted, any()}.
 sql_transaction(Host, Queries)
     when is_list(Queries) ->
@@ -177,7 +178,7 @@ sync_send_event(Proc, Msg, Timeout) ->
 	    {error, Reason}
     end.
 
--spec sql_query_t(sql_query()) -> sql_query_result().
+-spec sql_query_t(sql_query(T)) -> sql_query_result(T).
 %% This function is intended to be used from inside an sql_transaction:
 sql_query_t(Query) ->
     QRes = sql_query_internal(Query),
@@ -683,7 +684,14 @@ sql_query_internal(#sql_query{} = Query) ->
                             pgsql_sql_query(Query)
                     end;
                 mysql ->
-                    generic_sql_query(Query);
+		    case {Query#sql_query.flags, ejabberd_option:sql_prepared_statements(State#state.host)} of
+			{1, _} ->
+			    generic_sql_query(Query);
+			{_, false} ->
+			    generic_sql_query(Query);
+			_ ->
+			    mysql_prepared_execute(Query, State)
+		    end;
                 sqlite ->
                     sqlite_sql_query(Query)
             end
@@ -862,6 +870,24 @@ pgsql_execute_sql_query(SQLQuery, State) ->
     Res = pgsql_execute_to_odbc(ExecuteRes),
     sql_query_format_res(Res, SQLQuery).
 
+mysql_prepared_execute(#sql_query{hash = Hash} = Query, State) ->
+    ValEsc = #sql_escape{like_escape = fun() -> ignore end, _ = fun(X) -> X end},
+    TypesEsc = #sql_escape{string = fun(_) -> string end,
+			   integer = fun(_) -> integer end,
+			   boolean = fun(_) -> bool end,
+			   in_array_string = fun(_) -> string end,
+			   like_escape = fun() -> ignore end},
+    Val = [X || X <- (Query#sql_query.args)(ValEsc), X /= ignore],
+    Types = [X || X <- (Query#sql_query.args)(TypesEsc), X /= ignore],
+    QueryFn = fun() ->
+	PrepEsc = #sql_escape{like_escape = fun() -> <<>> end, _ = fun(_) -> <<"?">> end},
+	(Query#sql_query.format_query)((Query#sql_query.args)(PrepEsc))
+	end,
+    QueryTimeout = query_timeout(State#state.host),
+    Res = p1_mysql_conn:prepared_query(State#state.db_ref, QueryFn, Hash, Val, Types,
+				       self(), [{timeout, QueryTimeout - 1000}]),
+    Res2 = mysql_to_odbc(Res),
+    sql_query_format_res(Res2, Query).
 
 sql_query_format_res({selected, _, Rows}, SQLQuery) ->
     Res =
@@ -1123,9 +1149,50 @@ get_db_version(#state{db_type = pgsql} = State) ->
             ?WARNING_MSG("Error getting pgsql version: ~p", [Res]),
             State
     end;
+get_db_version(#state{db_type = mysql, host = Host} = State) ->
+    DefaultUpsert = case lists:member(mysql_alternative_upsert, ejabberd_option:sql_flags(Host)) of
+			true -> 1;
+			_ -> 0
+		    end,
+    case mysql_to_odbc(p1_mysql_conn:squery(State#state.db_ref,
+					    [<<"select version();">>], self(),
+					    [{timeout, 5000},
+					     {result_type, binary}])) of
+	{selected, _, [SVersion]} ->
+	    case re:run(SVersion, <<"(\\d+)\\.(\\d+)(?:\\.(\\d+))?(?:-([^-]*))?">>,
+			[{capture, all_but_first, binary}]) of
+		{match, [V1, V2, V3, Type]} ->
+		    V = ((bin_to_int(V1)*1000)+bin_to_int(V2))*1000+bin_to_int(V3),
+		    TypeA = binary_to_atom(Type, utf8),
+		    Flags = case TypeA of
+				'MariaDB' -> DefaultUpsert;
+				_ when V >= 5007026 andalso V < 8000000 -> 1;
+				_ when V >= 8000020 -> 1;
+				_ -> DefaultUpsert
+			    end,
+		    State#state{db_version = {V, TypeA, Flags}};
+		{match, [V1, V2, V3]} ->
+		    V = ((bin_to_int(V1)*1000)+bin_to_int(V2))*1000+bin_to_int(V3),
+		    Flags = case V of
+				_ when V >= 5007026 andalso V < 8000000 -> 1;
+				_ when V >= 8000020 -> 1;
+				_ -> DefaultUpsert
+			    end,
+		    State#state{db_version = {V, unknown, Flags}};
+		_ ->
+		    ?WARNING_MSG("Error parsing mysql version: ~p", [SVersion]),
+		    State
+	    end;
+	Res ->
+	    ?WARNING_MSG("Error getting mysql version: ~p", [Res]),
+	    State
+    end;
 get_db_version(State) ->
     State.
 
+bin_to_int(<<>>) -> 0;
+bin_to_int(V) -> binary_to_integer(V).
+
 log(Level, Format, Args) ->
     case Level of
       debug -> ?DEBUG(Format, Args);
@@ -1159,9 +1226,19 @@ db_opts(Host) ->
 	    SSLOpts = get_ssl_opts(Transport, Host),
 	    case Type of
 		mssql ->
-		    [mssql, <<"DRIVER=ODBC;SERVER=", Server/binary, ";UID=", User/binary,
-			      ";DATABASE=", DB/binary ,";PWD=", Pass/binary,
-			      ";PORT=", (integer_to_binary(Port))/binary ,";CLIENT_CHARSET=UTF-8;">>, Timeout];
+                    case odbc_server_is_connstring(Server) of
+                        true ->
+                            [mssql, Server, Timeout];
+                        false ->
+                            Encryption = case Transport of
+                                tcp -> <<"">>;
+                                ssl -> <<";ENCRYPTION=require;ENCRYPT=yes">>
+                            end,
+                            [mssql, <<"DRIVER=ODBC;SERVER=", Server/binary, ";DATABASE=", DB/binary,
+                                      ";UID=", User/binary, ";PWD=", Pass/binary,
+                                      ";PORT=", (integer_to_binary(Port))/binary, Encryption/binary,
+                                      ";CLIENT_CHARSET=UTF-8;">>, Timeout]
+                    end;
 		_ ->
 		    [Type, Server, Port, DB, User, Pass, Timeout, Transport, SSLOpts]
 	    end
@@ -1171,6 +1248,8 @@ warn_if_ssl_unsupported(tcp, _) ->
     ok;
 warn_if_ssl_unsupported(ssl, pgsql) ->
     ok;
+warn_if_ssl_unsupported(ssl, mssql) ->
+    ok;
 warn_if_ssl_unsupported(ssl, mysql) ->
     ok;
 warn_if_ssl_unsupported(ssl, Type) ->
@@ -1203,7 +1282,7 @@ get_ssl_opts(ssl, Host) ->
 get_ssl_opts(tcp, _) ->
     [].
 
-init_mssql(Host) ->
+init_mssql_odbcinst(Host) ->
     Driver = ejabberd_option:sql_odbc_driver(Host),
     ODBCINST = io_lib:fwrite("[ODBC]~n"
 			     "Driver = ~s~n", [Driver]),
@@ -1225,6 +1304,19 @@ init_mssql(Host) ->
 	    Err
     end.
 
+init_mssql(Host) ->
+    Server = ejabberd_option:sql_server(Host),
+    case odbc_server_is_connstring(Server) of
+        true -> ok;
+        false -> init_mssql_odbcinst(Host)
+    end.
+
+odbc_server_is_connstring(Server) ->
+    case binary:match(Server, <<"=">>) of
+        nomatch -> false;
+        _ -> true
+    end.
+
 write_file_if_new(File, Payload) ->
     case filelib:is_file(File) of
 	true -> ok;
