@@ -33,6 +33,7 @@
          installed_command/0, installed/0, installed/1,
          install/1, uninstall/1, upgrade/0, upgrade/1, add_paths/0,
          add_sources/1, add_sources/2, del_sources/1, modules_dir/0,
+         install_contrib_modules/2,
          config_dir/0, get_commands_spec/0]).
 -export([modules_configs/0, module_ebin_dir/1]).
 -export([compile_erlang_file/2, compile_elixir_file/2]).
@@ -48,7 +49,7 @@
 -include("translate.hrl").
 -include_lib("xmpp/include/xmpp.hrl").
 
--define(REPOS, "https://github.com/processone/ejabberd-contrib").
+-define(REPOS, "git@github.com:processone/ejabberd-contrib.git").
 
 -record(state, {}).
 
@@ -66,7 +67,7 @@ init([]) ->
     {ok, #state{}}.
 
 add_paths() ->
-    [code:add_patha(module_ebin_dir(Module))
+    [code:add_pathsz([module_ebin_dir(Module)|module_deps_dirs(Module)])
      || {Module, _} <- installed()].
 
 handle_call(Request, From, State) ->
@@ -215,10 +216,13 @@ installed_command() ->
     [short_spec(Item) || Item <- installed()].
 
 install(Module) when is_atom(Module) ->
-    install(misc:atom_to_binary(Module));
+    install(misc:atom_to_binary(Module), undefined);
 install(Package) when is_binary(Package) ->
+    install(Package, undefined).
+
+install(Package, Config) when is_binary(Package) ->
     Spec = [S || {Mod, S} <- available(), misc:atom_to_binary(Mod)==Package],
-    case {Spec, installed(Package), is_contrib_allowed()} of
+    case {Spec, installed(Package), is_contrib_allowed(Config)} of
         {_, _, false} ->
             {error, not_allowed};
         {[], _, _} ->
@@ -227,13 +231,14 @@ install(Package) when is_binary(Package) ->
             {error, conflict};
         {[Attrs], _, _} ->
             Module = misc:binary_to_atom(Package),
-            case compile_and_install(Module, Attrs) of
+            case compile_and_install(Module, Attrs, Config) of
                 ok ->
-                    code:add_patha(module_ebin_dir(Module)),
-                    ejabberd_config:reload(),
+                    code:add_pathsz([module_ebin_dir(Module)|module_deps_dirs(Module)]),
+                    ejabberd_config_reload(Config),
                     copy_commit_json(Package, Attrs),
-                    case erlang:function_exported(Module, post_install, 0) of
-                        true -> Module:post_install();
+                    ModuleRuntime = get_runtime_module_name(Module),
+                    case erlang:function_exported(ModuleRuntime, post_install, 0) of
+                        true -> ModuleRuntime:post_install();
                         _ -> ok
                     end;
                 Error ->
@@ -242,21 +247,30 @@ install(Package) when is_binary(Package) ->
             end
     end.
 
+ejabberd_config_reload(Config) when is_list(Config) ->
+    %% Don't reload config when ejabberd is starting
+    %% because it will be reloaded after installing
+    %% all the external modules from install_contrib_modules
+    ok;
+ejabberd_config_reload(undefined) ->
+    ejabberd_config:reload().
+
 uninstall(Module) when is_atom(Module) ->
     uninstall(misc:atom_to_binary(Module));
 uninstall(Package) when is_binary(Package) ->
     case installed(Package) of
         true ->
             Module = misc:binary_to_atom(Package),
-            case erlang:function_exported(Module, pre_uninstall, 0) of
-                true -> Module:pre_uninstall();
+            ModuleRuntime = get_runtime_module_name(Module),
+            case erlang:function_exported(ModuleRuntime, pre_uninstall, 0) of
+                true -> ModuleRuntime:pre_uninstall();
                 _ -> ok
             end,
-            [catch gen_mod:stop_module(Host, Module)
+            [catch gen_mod:stop_module(Host, ModuleRuntime)
              || Host <- ejabberd_option:hosts()],
-            code:purge(Module),
-            code:delete(Module),
-            code:del_path(module_ebin_dir(Module)),
+            code:purge(ModuleRuntime),
+            code:delete(ModuleRuntime),
+            [code:del_path(PathDelete) || PathDelete <- [module_ebin_dir(Module)|module_deps_dirs(Module)]],
             delete_path(module_lib_dir(Module)),
             ejabberd_config:reload();
         false ->
@@ -280,7 +294,7 @@ add_sources(Module, Path) when is_atom(Module), is_list(Path) ->
 add_sources(Package, Path) when is_binary(Package), is_list(Path) ->
     DestDir = sources_dir(),
     RepDir = filename:join(DestDir, module_name(Path)),
-    delete_path(RepDir),
+    delete_path(RepDir, binary_to_list(Package)),
     case filelib:ensure_dir(RepDir) of
         ok ->
             case {string:left(Path, 4), string:right(Path, 2)} of
@@ -343,6 +357,8 @@ geturl(Url) ->
     case httpc:request(get, {Url, [UA]}, User, [{body_format, binary}], ext_mod) of
         {ok, {{_, 200, _}, Headers, Response}} ->
             {ok, Headers, Response};
+        {ok, {{_, 403, Reason}, _Headers, _Response}} ->
+            {error, Reason};
         {ok, {{_, Code, _}, _Headers, Response}} ->
             {error, {Code, Response}};
         {error, Reason} ->
@@ -390,8 +406,9 @@ extract_github_master(Repos, DestDir) ->
     case extract(zip, geturl(Url++"/archive/master.zip"), DestDir) of
         ok ->
             RepDir = filename:join(DestDir, module_name(Repos)),
-            file:rename(RepDir++"-master", RepDir),
-            maybe_write_commit_json(Url, RepDir);
+            RepDirSpec = filename:join(DestDir, module_spec_name(RepDir)),
+            file:rename(RepDir++"-master", RepDirSpec),
+            maybe_write_commit_json(Url, RepDirSpec);
         Error ->
             Error
     end.
@@ -426,6 +443,9 @@ delete_path(Path) ->
             file:delete(Path)
     end.
 
+delete_path(Path, Package) ->
+    delete_path(filename:join(filename:dirname(Path), Package)).
+
 modules_dir() ->
     DefaultDir = filename:join(getenv("HOME"), ".ejabberd-modules"),
     getenv("CONTRIB_MODULES_PATH", DefaultDir).
@@ -464,6 +484,14 @@ module_src_dir(Package) ->
 module_name(Id) ->
     filename:basename(filename:rootname(Id)).
 
+module_spec_name(Path) ->
+    case filelib:wildcard(filename:join(Path++"-master", "*.spec")) of
+        "" ->
+            module_name(Path);
+        ModuleName ->
+            filename:basename(ModuleName, ".spec")
+    end.
+
 module(Id) ->
     misc:binary_to_atom(iolist_to_binary(module_name(Id))).
 
@@ -483,7 +511,13 @@ modules_spec(Dir, Path) ->
 short_spec({Module, Attrs}) when is_atom(Module), is_list(Attrs) ->
     {Module, proplists:get_value(summary, Attrs, "")}.
 
-is_contrib_allowed() ->
+is_contrib_allowed(Config) when is_list(Config) ->
+    case lists:keyfind(allow_contrib_modules, 1, Config) of
+        false -> true;
+        {_, false} -> false;
+        {_, true} -> true
+    end;
+is_contrib_allowed(undefined) ->
     ejabberd_option:allow_contrib_modules().
 
 %% -- build functions
@@ -526,7 +560,7 @@ check_sources(Module) ->
         _ -> {error, Result}
     end.
 
-compile_and_install(Module, Spec) ->
+compile_and_install(Module, Spec, Config) ->
     SrcDir = module_src_dir(Module),
     LibDir = module_lib_dir(Module),
     case filelib:is_dir(SrcDir) of
@@ -534,7 +568,7 @@ compile_and_install(Module, Spec) ->
             case compile_deps(SrcDir) of
                 ok ->
                     case compile(SrcDir) of
-                        ok -> install(Module, Spec, SrcDir, LibDir);
+                        ok -> install(Module, Spec, SrcDir, LibDir, Config);
                         Error -> Error
                     end;
                 Error ->
@@ -543,7 +577,7 @@ compile_and_install(Module, Spec) ->
         false ->
             Path = proplists:get_value(url, Spec, ""),
             case add_sources(Module, Path) of
-                ok -> compile_and_install(Module, Spec);
+                ok -> compile_and_install(Module, Spec, Config);
                 Error -> Error
             end
     end.
@@ -648,18 +682,19 @@ compile_elixir_file(_, File) ->
     {error, {compilation_failed, File}}.
 -endif.
 
-install(Module, Spec, SrcDir, LibDir) ->
+install(Module, Spec, SrcDir, LibDir, Config) ->
     {ok, CurDir} = file:get_cwd(),
     file:set_cwd(SrcDir),
     Files1 = [{File, copy(File, filename:join(LibDir, File))}
                   || File <- filelib:wildcard("{ebin,priv,conf,include}/**")],
     Files2 = [{File, copy(File, filename:join(LibDir, filename:join(lists:nthtail(2,filename:split(File)))))}
-                  || File <- filelib:wildcard("deps/*/{ebin,priv}/**")],
+                  || File <- filelib:wildcard("deps/*/ebin/**")],
+    Files3 = [{File, copy(File, filename:join(LibDir, File))}
+                  || File <- filelib:wildcard("deps/*/priv/**")],
     Errors = lists:dropwhile(fun({_, ok}) -> true;
                                 (_) -> false
-            end, Files1++Files2),
-    copy_priv_files(LibDir),
-    inform_module_configuration(Module, LibDir, Files1),
+            end, Files1++Files2++Files3),
+    inform_module_configuration(Module, LibDir, Files1, Config),
     Result = case Errors of
         [{F, {error, E}}|_] ->
             {error, {F, E}};
@@ -671,30 +706,37 @@ install(Module, Spec, SrcDir, LibDir) ->
     file:set_cwd(CurDir),
     Result.
 
-copy_priv_files(LibDir) ->
-    file:set_cwd(LibDir),
-    EjabberdLibDir = code:lib_dir(ejabberd),
-    [{File, copy(File, filename:join(EjabberdLibDir, File))}
-                  || File <- filelib:wildcard("{priv}/**")].
-
-inform_module_configuration(Module, LibDir, Files1) ->
+inform_module_configuration(Module, LibDir, Files1, Config) ->
     Res = lists:filter(fun({[$c, $o, $n, $f |_], ok}) -> true;
                           (_) -> false
             end, Files1),
-    case Res of
-        [{ConfigPath, ok}] ->
+    AlreadyConfigured = lists:keymember(Module, 1, get_modules(Config)),
+    case {Res, AlreadyConfigured} of
+        {[{ConfigPath, ok}], false} ->
             FullConfigPath = filename:join(LibDir, ConfigPath),
             io:format("Module ~p has been installed and started.~n"
                       "It's configured in the file:~n  ~s~n"
                       "Configure the module in that file, or remove it~n"
                       "and configure in your main ejabberd.yml~n",
                       [Module, FullConfigPath]);
-        [] ->
+        {[{ConfigPath, ok}], true} ->
+            FullConfigPath = filename:join(LibDir, ConfigPath),
+            file:rename(FullConfigPath, FullConfigPath++".example"),
+            io:format("Module ~p has been installed and started.~n"
+                      "The ~p configuration in your ejabberd.yml is used.~n",
+                      [Module, Module]);
+        {[], _} ->
             io:format("Module ~p has been installed.~n"
                       "Now you can configure it in your ejabberd.yml~n",
                       [Module])
     end.
 
+get_modules(Config) when is_list(Config) ->
+    {modules, Modules} = lists:keyfind(modules, 1, Config),
+    Modules;
+get_modules(undefined) ->
+    ejabberd_config:get_option(modules).
+
 %% -- minimalist rebar spec parser, only support git
 
 fetch_rebar_deps(SrcDir) ->
@@ -736,6 +778,14 @@ rebar_dep({App, _, {git, Url, Ref}}) ->
      "; (cd "++filename:basename(App)++
      "; git checkout -q "++Ref++")"}.
 
+module_deps_dirs(Module) ->
+    SrcDir = module_src_dir(Module),
+    LibDir = module_lib_dir(Module),
+    DepsDir = filename:join(LibDir, "deps"),
+    Deps = rebar_deps(filename:join(SrcDir, "rebar.config"))
+      ++ rebar_deps(filename:join(SrcDir, "rebar.config.script")),
+    [filename:join(DepsDir, App) || {App, _Cmd} <- Deps].
+
 %% -- YAML spec parser
 
 consult(File) ->
@@ -763,10 +813,14 @@ maybe_write_commit_json(Url, RepDir) ->
 write_commit_json(Url, RepDir) ->
     Url2 = string_replace(Url, "https://github.com", "https://api.github.com/repos"),
     BranchUrl = lists:flatten(Url2 ++ "/branches/master"),
-    {ok, _Headers, Body} = geturl(BranchUrl),
-    {ok, F} = file:open(filename:join(RepDir, "COMMIT.json"), [raw, write]),
-    file:write(F, Body),
-    file:close(F).
+    case geturl(BranchUrl) of
+        {ok, _Headers, Body} ->
+            {ok, F} = file:open(filename:join(RepDir, "COMMIT.json"), [raw, write]),
+            file:write(F, Body),
+            file:close(F);
+        {error, Reason} ->
+            Reason
+    end.
 
 find_commit_json(Attrs) ->
     {_, FromPath} = lists:keyfind(path, 1, Attrs),
@@ -985,6 +1039,26 @@ get_module_status(Module) ->
             unknown
     end.
 
+%% When a module named mod_whatever in ejabberd-modules
+%% is written in Elixir, its runtime name is 'Elixir.ModWhatever'
+get_runtime_module_name(Module) ->
+    case is_elixir_module(Module) of
+        true -> elixir_module_name(Module);
+        false -> Module
+    end.
+
+is_elixir_module(Module) ->
+    LibDir = module_src_dir(Module),
+    Lib = filename:join(LibDir, "lib"),
+    Src = filename:join(LibDir, "src"),
+    case {filelib:wildcard(Lib++"/*.{ex}"),
+          filelib:wildcard(Src++"/*.{erl}")} of
+        {[_ | _], []} ->
+            true;
+        {[], [_ | _]} ->
+            false
+    end.
+
 %% Converts mod_some_thing to Elixir.ModSomeThing
 elixir_module_name(ModAtom) ->
     list_to_atom("Elixir." ++ elixir_module_name("_" ++ atom_to_list(ModAtom), [])).
@@ -1210,3 +1284,14 @@ list_modules_parse_uninstall(Query) ->
       end,
       installed()),
     ok.
+
+install_contrib_modules(Modules, Config) ->
+    lists:filter(fun(Module) ->
+                         case install(misc:atom_to_binary(Module), Config) of
+                             {error, conflict} ->
+                                 false;
+                             ok ->
+                                 true
+                         end
+                 end,
+                 Modules).
